﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace Phidget22.ExampleUtils
{
	public partial class DataGraphBox : Form
	{

		private double chartTime = 20;
		private bool pause = false;

		private int latestDataInterval = -100;

		private enum ChartType
		{
			DataPoints,
			FFT,
			AllanDeviation
		};

		private ChartType chartType = ChartType.DataPoints;

		private String filename = "";

		private DateTime prevGraphTime;

		List<double[]> allDataPoints = new List<double[]>();

		System.IO.StreamWriter fs;

		public DataGraphBox(Form owner, String title)
		{
			InitializeComponent();
			this.Owner = owner;
			IntPtr dummy = this.Handle; //Force the form to load before it's shown so we can call invoke on it.
			graph.ChartAreas["ChartArea1"].AxisX.LabelStyle.Format = "hh:mm:ss tt";
			graph.Titles[0].Text = title;
			this.Text = title;
			graph.ChartAreas["ChartArea1"].AxisX.Interval = 5;
			graph.ChartAreas["ChartArea1"].AxisX.IntervalType = System.Windows.Forms.DataVisualization.Charting.DateTimeIntervalType.Seconds;
			ChartTimeLabel.Text = chartTime.ToString() + "s";
			ChartTimeTrackbar.Value = (int)(chartTime / 5);
			FileSizeLabel.Text = "";
			FileNameLabel.Text = "";
			prevGraphTime = DateTime.Now;
			chartTypeBox.SelectedIndex = 0;
			filterTypeBox.SelectedIndex = 0;
			filterWarningLabel.Text = "";
		}

		public void addData(double dataPoint) //Overloaded function to try to support older versions.
		{
			addData(dataPoint, -1);
		}

		public void addData(double dataPoint, int dataInterval)
		{
			bool supportAdvancedFeatures = (dataInterval != -1);
			if (supportAdvancedFeatures == false)
			{
				graphTypeLabel.Hide();
				chartTypeBox.Hide();
				chartTypeBox.SelectedIndex = 0;
				filterTypeLabel.Hide();
				filterWarningLabel.Hide();
				filterSectionLabel.Hide();
				filterBar.Hide();
				filterLabel.Hide();
				minSamplesLabel.Hide();
				maxSamplesLabel.Hide();
				filterTypeBox.Hide();
			}

			if(dataInterval != latestDataInterval)
			{
				latestDataInterval = dataInterval;
				updateFilterBarMax();
			}
			
			if (pause)
				return;
			try {
				if (allDataPoints.Count > 5)
				{
					DateTime endTime = DateTime.FromOADate(allDataPoints.Last()[0]);
					double diff = (DateTime.Now).Subtract(endTime).TotalSeconds;
					double seconds;
					do
					{
						DateTime startTime = DateTime.FromOADate(allDataPoints.First()[0]);
						seconds = endTime.Subtract(startTime).TotalSeconds;
						if (seconds > chartTime)
						{
							allDataPoints.RemoveAt(0);
						}
					} while (seconds > chartTime);
				}
				DateTime nowTime = System.DateTime.Now;
				allDataPoints.Add(new double[] { nowTime.ToOADate(), dataPoint });

				if (filename != "")
				{
					//System.IO.StreamWriter fs = new System.IO.StreamWriter(filename, true);
					fs.WriteLine(nowTime.ToString("yyyy/MM/dd HH:mm:ss.fff") + "," + dataPoint.ToString());
					Int64 lengthKB = fs.BaseStream.Length / 1024;
					FileSizeLabel.Text = "File Size: " + lengthKB.ToString() + "kB";
					//fs.Close();
				}

				if (chartType == ChartType.DataPoints)
				{
					if (graph.Series[0].Points.Count > 5)
					{
						DateTime endTime = DateTime.FromOADate(graph.Series[0].Points.Last().XValue);
						double diff = (DateTime.Now).Subtract(endTime).TotalSeconds;
						if (DateTime.Now.Subtract(endTime).TotalSeconds < 0.02)
						{

							return;
						}
						double seconds;
						do
						{
							DateTime startTime = DateTime.FromOADate(graph.Series[0].Points.First().XValue);
							seconds = endTime.Subtract(startTime).TotalSeconds;
							if (seconds > chartTime)
							{
								graph.Series[0].Points.RemoveAt(0);
							}
						} while (seconds > chartTime);
					}

					double filteredPoint = 0;
					if (filterLength != 0)
					{
						if(allDataPoints.Count < filterLength)
							return;
						for (int i = 0; i < filterLength; i++)
						{
							filteredPoint += allDataPoints[(allDataPoints.Count-1) - i][1];
						}
						filteredPoint /= filterLength;
						if (filterType == FilterType.HPF)
							filteredPoint = dataPoint - filteredPoint; //slightly hacky, but improved feel to the user.
					}
					else
						filteredPoint = dataPoint;

					graph.Series[0].Points.AddXY(System.DateTime.Now, filteredPoint);
					graph.ResetAutoValues();
				}
				else if (chartType == ChartType.FFT)
				{
					double diff = DateTime.Now.Subtract(prevGraphTime).TotalSeconds;

					if (DateTime.Now.Subtract(prevGraphTime).TotalSeconds < (chartTime / 120))
						return;

					prevGraphTime = DateTime.Now;
					doFFTGraph(dataInterval);
				}
				else if(chartType == ChartType.AllanDeviation)
				{
					if (DateTime.Now.Subtract(prevGraphTime).TotalSeconds < ((chartTime <= 900) ? (0.5) : (chartTime/1800)))
						return;

					calculateAllanDeviation(dataInterval);
					prevGraphTime = DateTime.Now;
				}
			} catch (Exception ex)
			{
				Console.WriteLine(ex);
			}
		}

		public void doFFTGraph(double dataInterval)
		{
			//count must be a power of 2.
			int count = 1;
			while (count <= allDataPoints.Count)
				count *= 2;
			count /= 2;

			if (count < 4)
				return;

			double ms = 0;
			double highDiff = -1;
			double lowDiff = 1e6;
			for (int i = 1; i < allDataPoints.Count; i++)
			{
				double timeDiff = (DateTime.FromOADate(allDataPoints[i][0]) - DateTime.FromOADate(allDataPoints[i - 1][0])).Milliseconds;
				if (timeDiff > highDiff)
					highDiff = timeDiff;
				if (timeDiff < lowDiff)
					lowDiff = timeDiff;

				ms += timeDiff;
			}
			ms /= allDataPoints.Count - 1;
			Math.Round(ms);
			if (Math.Abs(dataInterval - ms) > 2)
			{
				graph.Series[0].Points.Clear();
				allDataPoints.Clear();
				return;
			}
			ms = dataInterval;

		//	if (highDiff - lowDiff > 60)
		//		return;

			//double startTime = data[0].X;
			double maxFrequency = (1000.0 / ms) / 2; //half of the datarate
			double resolution = maxFrequency / (count / 2.0);

			Exocortex.DSP.ComplexF[] complexData = new Exocortex.DSP.ComplexF[count];

			for (int i = 0; i < count; ++i)
			{
				// Fill the complex data
				complexData[i].Re = (float)allDataPoints[(allDataPoints.Count-count)+i][1]; // Add your real part here
			}

			// FFT the time domain data to get frequency domain data
			Exocortex.DSP.Fourier.FFT(complexData, Exocortex.DSP.FourierDirection.Forward);

			float[] mag_dat_buffer = new float[complexData.Length];

			// Loop through FFT'ed data and do something with it
			graph.Series[0].Points.Clear();
			//only the first half - 2nd half is the data reversed
			List<freqIntensity> intensityList = new List<freqIntensity>();
			for (int i = 1; i < complexData.Length / 2; ++i)
			{
				double intensity = Math.Sqrt(complexData[i].Re * complexData[i].Re + complexData[i].Im * complexData[i].Im);
				intensity /= complexData.Length/2;
				double frequency = i * resolution;

				intensityList.Add(new freqIntensity(frequency, intensity));

				// Calculate magnitude or do something with the new complex data
				graph.Series[0].Points.AddXY(frequency, intensity);
			}
			intensityList.Sort();

			//graph.ResetAutoValues();
			graph.ChartAreas["ChartArea1"].AxisX.MinorGrid.Interval = 5;
			graph.ChartAreas["ChartArea1"].AxisX.MinorGrid.Enabled = true;
		}

		private void DataGraphBox_FormClosing(object sender, FormClosingEventArgs e)
		{
			if (e.CloseReason == CloseReason.UserClosing)
			{
				this.Hide();
				e.Cancel = true;
				if (fs != null)
				{
					fs.Close();
				}
				filename = "";
				SaveButton.Text = "Save to CSV";
			}
		}

		private void updateFilterBarMax()
		{
			if (latestDataInterval > 0)
			{
				if (filterType == FilterType.None)
				{
					maxSamplesLabel.Text = "1";
					filterLabel.Text = "0 (0ms)";
					return;
				}

				int tmpMax = (int)((chartTime * 1000) / latestDataInterval);
				if (tmpMax > 1000)
					tmpMax = 1000;
				if (tmpMax < filterBar.Minimum)
					tmpMax = filterBar.Minimum;
				filterBar.Maximum = tmpMax;
				if (filterBar.Value > filterBar.Maximum)
					filterBar.Value = filterBar.Minimum;
				maxSamplesLabel.Text = tmpMax.ToString();
				filterLength = filterBar.Value;
				filterLabel.Text = filterLength.ToString() + " (" + (filterLength * latestDataInterval).ToString() + "ms)";
				if (filterLength * latestDataInterval > chartTime * 1000)
					filterWarningLabel.Text = " WARN: Filter longer than Chart Length. No data will be shown.";
				else
					filterWarningLabel.Text = "";
			}
		}
		private void trackBar1_Scroll(object sender, EventArgs e)
		{
			chartTime = ChartTimeTrackbar.Value * 5;
			ChartTimeLabel.Text = chartTime.ToString() + "s";
			updateFilterBarMax();
		}

		private void ClearButton_Click(object sender, EventArgs e)
		{
			graph.Series[0].Points.Clear();
			allDataPoints.Clear();
			graph.ChartAreas["ChartArea1"].AxisX.IsLogarithmic = false;
			graph.ChartAreas["ChartArea1"].AxisY.IsLogarithmic = false;
		}

		private void SaveButton_Click(object sender, EventArgs e)
		{
			if (filename != "")
			{
				filename = "";
				fs.Close();
				SaveButton.Text = "Save to CSV";
				return;
			}

			// Displays a SaveFileDialog so the user can save the Image
			// assigned to Button2.
			SaveFileDialog saveFileDialog1 = new SaveFileDialog();
			saveFileDialog1.Filter = "CSV file (.csv)|*.csv| All Files (.)|*.*";
			saveFileDialog1.Title = "Save to CSV File";
			saveFileDialog1.ShowDialog();

			Int64 lengthKB;

			// If the file name is not an empty string open it for saving.
			if (saveFileDialog1.FileName != "")
			{
				fs = new System.IO.StreamWriter(saveFileDialog1.OpenFile());
				filename = saveFileDialog1.FileName;
				FileNameLabel.Text = "File: " + filename;
				FileNameLabel.Location = new Point(this.Width - (FileNameLabel.Width + 30), FileNameLabel.Location.Y);

				switch (chartType) {
					case ChartType.DataPoints:
						fs.WriteLine("Date," + this.Text);
						foreach (double[] dataPoint in allDataPoints)
						{
							DateTime pointTime = DateTime.FromOADate(dataPoint[0]);
							fs.WriteLine(pointTime.ToString("yyyy/MM/dd HH:mm:ss.fff") + "," + dataPoint[1].ToString());
						}

						lengthKB = fs.BaseStream.Length / 1024;
						FileSizeLabel.Text = "File Size: " + lengthKB.ToString() + "kB";

						//fs.Close();

						if (pause) //Don't continue saving to a file if the data was paused
							filename = "";
						else
							SaveButton.Text = "Stop Saving";
						break;
					case ChartType.FFT:
						fs.WriteLine("Frequency," + this.Text);
						foreach (System.Windows.Forms.DataVisualization.Charting.DataPoint dataPoint in graph.Series[0].Points)
						{
							fs.WriteLine(dataPoint.XValue.ToString() + "," + dataPoint.YValues[0].ToString());
						}

						lengthKB = fs.BaseStream.Length / 1024;
						FileSizeLabel.Text = "File Size: " + lengthKB.ToString() + "kB";

						fs.Close();
						filename = "";
						break;
					case ChartType.AllanDeviation:
						fs.WriteLine("Timespan (s)," + "Allan Deviation");
						foreach (System.Windows.Forms.DataVisualization.Charting.DataPoint dataPoint in graph.Series[0].Points)
						{
							fs.WriteLine(dataPoint.XValue.ToString() + "," + dataPoint.YValues[0].ToString());
						}

						lengthKB = fs.BaseStream.Length / 1024;
						FileSizeLabel.Text = "File Size: " + lengthKB.ToString() + "kB";

						fs.Close();
						filename = "";
						break;
				}
			}
		}

		private void button1_Click(object sender, EventArgs e)
		{
			if (pause == false) {
				pause = true;
				PauseButton.Text = "Resume";
			}
			else
			{
				pause = false;
				PauseButton.Text = "Pause";
			}
		}

		private void chartTypeBox_SelectedIndexChanged(object sender, EventArgs e)
		{
			if (filename != "")
			{
				filename = "";
				fs.Close();
				SaveButton.Text = "Save to CSV";
				return;
			}

			if (chartTypeBox.SelectedIndex == 0)
			{
				graph.Series[0].Points.Clear();
				chartType = ChartType.DataPoints;
				graph.ChartAreas["ChartArea1"].AxisX.LabelStyle.Format = "hh:mm:ss tt";
				graph.ChartAreas["ChartArea1"].AxisX.Interval = 5;
				graph.ChartAreas["ChartArea1"].AxisX.IntervalType = System.Windows.Forms.DataVisualization.Charting.DateTimeIntervalType.Seconds;
				graph.Series[0].XValueType = System.Windows.Forms.DataVisualization.Charting.ChartValueType.DateTime;
				graph.ChartAreas["ChartArea1"].AxisX.Title = "Time";
				graph.ChartAreas["ChartArea1"].AxisY.Title = "";
				graph.ChartAreas["ChartArea1"].AxisX.IsLogarithmic = false;
				graph.ChartAreas["ChartArea1"].AxisY.IsLogarithmic = false;
				graph.ChartAreas["ChartArea1"].AxisX.MinorGrid.Interval = 0;
				graph.ChartAreas["ChartArea1"].AxisY.MinorGrid.Interval = 0;
				graph.ChartAreas["ChartArea1"].AxisX.MinorGrid.Enabled = false;
				graph.ChartAreas["ChartArea1"].AxisY.MinorGrid.Enabled = false;
				graph.ChartAreas["ChartArea1"].AxisX.Minimum = Double.NaN;
				graph.ChartAreas["ChartArea1"].AxisX.Maximum = Double.NaN;
				graph.ChartAreas["ChartArea1"].AxisY.Minimum = Double.NaN;
				graph.ChartAreas["ChartArea1"].AxisY.Maximum = Double.NaN;
				graph.ChartAreas["ChartArea1"].InnerPlotPosition.Auto = false;
				graph.ChartAreas["ChartArea1"].InnerPlotPosition.Width = 93;
				graph.ChartAreas["ChartArea1"].InnerPlotPosition.X = 5;
				graph.ChartAreas["ChartArea1"].InnerPlotPosition.Height = 80;
				graph.ChartAreas["ChartArea1"].InnerPlotPosition.Y = 3; graph.ChartAreas["ChartArea1"].InnerPlotPosition.Width = 93;
				graph.ChartAreas["ChartArea1"].InnerPlotPosition.X = 5;
				ChartTimeTrackbar.Maximum = 12;
				maxTimeLabel.Text = "60s";
				chartTime = ChartTimeTrackbar.Value * 5;
				ChartTimeLabel.Text = chartTime.ToString() + "s";
				filterTypeBox.Enabled = true;
				filterBar.Enabled = filterType != FilterType.None;
			}
			else if (chartTypeBox.SelectedIndex == 1)
			{
				graph.Series[0].Points.Clear();
				chartType = ChartType.FFT;
				graph.ChartAreas["ChartArea1"].AxisX.LabelStyle.Format = "";
				graph.ChartAreas["ChartArea1"].AxisX.Interval = 0;
				graph.ChartAreas["ChartArea1"].AxisX.IntervalType = System.Windows.Forms.DataVisualization.Charting.DateTimeIntervalType.NotSet;
				graph.Series[0].XValueType = System.Windows.Forms.DataVisualization.Charting.ChartValueType.Double;
				graph.ChartAreas["ChartArea1"].AxisX.Title = "Frequency (Hz)";
				graph.ChartAreas["ChartArea1"].AxisY.Title = "";
				graph.ChartAreas["ChartArea1"].AxisX.IsLogarithmic = false;
				graph.ChartAreas["ChartArea1"].AxisY.IsLogarithmic = false;
				graph.ChartAreas["ChartArea1"].AxisX.MinorGrid.Interval = 0;
				graph.ChartAreas["ChartArea1"].AxisY.MinorGrid.Interval = 0;
				graph.ChartAreas["ChartArea1"].AxisX.MinorGrid.Enabled = false;
				graph.ChartAreas["ChartArea1"].AxisY.MinorGrid.Enabled = false;
				graph.ChartAreas["ChartArea1"].AxisX.Minimum = Double.NaN;
				graph.ChartAreas["ChartArea1"].AxisX.Maximum = Double.NaN;
				graph.ChartAreas["ChartArea1"].AxisY.Minimum = Double.NaN;
				graph.ChartAreas["ChartArea1"].AxisY.Maximum = Double.NaN;
				graph.ChartAreas["ChartArea1"].InnerPlotPosition.Auto = true;
				ChartTimeTrackbar.Maximum = 12;
				maxTimeLabel.Text = "60s";
				chartTime = ChartTimeTrackbar.Value * 5;
				ChartTimeLabel.Text = chartTime.ToString() + "s";
				filterTypeBox.Enabled = false;
				filterTypeBox.SelectedIndex = 0;
				filterBar.Enabled = false;
			}
			else if (chartTypeBox.SelectedIndex == 2)
			{
				graph.Series[0].Points.Clear();
				chartType = ChartType.AllanDeviation;
				graph.ChartAreas["ChartArea1"].AxisX.LabelStyle.Format = "";
				graph.ChartAreas["ChartArea1"].AxisX.Interval = 0;
				graph.ChartAreas["ChartArea1"].AxisX.IntervalType = System.Windows.Forms.DataVisualization.Charting.DateTimeIntervalType.NotSet;
				graph.Series[0].XValueType = System.Windows.Forms.DataVisualization.Charting.ChartValueType.Double;
				graph.ChartAreas["ChartArea1"].AxisX.Title = "Time Period (s)";
				graph.ChartAreas["ChartArea1"].AxisY.Title = "Allan Standard Deviation";
				//graph.ChartAreas["ChartArea1"].AxisX.IsLogarithmic = true;
				graph.ChartAreas["ChartArea1"].AxisX.MinorGrid.Enabled = true;
				graph.ChartAreas["ChartArea1"].AxisX.MinorGrid.Interval = 1;
				//graph.ChartAreas["ChartArea1"].AxisY.IsLogarithmic = true;
				graph.ChartAreas["ChartArea1"].AxisY.MinorGrid.Enabled = true;
				graph.ChartAreas["ChartArea1"].AxisY.MinorGrid.Interval = 2;
				graph.ChartAreas["ChartArea1"].InnerPlotPosition.Auto = true;
				ChartTimeTrackbar.Maximum = 360;
				maxTimeLabel.Text = "1800s (30min)";
				filterTypeBox.Enabled = false;
				filterTypeBox.SelectedIndex = 0;
				filterBar.Enabled = false;
			}
		}

		public class freqIntensity : IComparable
		{
			public double freq, intensity;
			public freqIntensity(double freq, double intensity)
			{
				this.freq = freq;
				this.intensity = intensity;
			}

			public int CompareTo(object obj)
			{
				freqIntensity other = (freqIntensity)obj;
				return other.intensity.CompareTo(intensity);
			}
		}

		public void calculateAllanDeviation(double dataInterval)
		{
			double tau0 = dataInterval/1000.0; //Calculate the sampling period
			int dataLength = allDataPoints.Count; //Calculate N
			List<double> dev = new List<double>(); //Create empty array to store the output.
			List<double> actualTau = new List<double>();

			if (dataLength < 5)
				return;

			double ms = 0;
			double highDiff = -1;
			double lowDiff = 1e6;
			for (int i = 1; i < allDataPoints.Count; i++)
			{
				double timeDiff = (DateTime.FromOADate(allDataPoints[i][0]) - DateTime.FromOADate(allDataPoints[i - 1][0])).Milliseconds;
				if (timeDiff > highDiff)
					highDiff = timeDiff;
				if (timeDiff < lowDiff)
					lowDiff = timeDiff;

				ms += timeDiff;
			}
			ms /= allDataPoints.Count - 1;
			Math.Round(ms);
			if (Math.Abs(dataInterval - ms) > 2)
			{
				graph.ChartAreas["ChartArea1"].AxisX.IsLogarithmic = false;
				graph.ChartAreas["ChartArea1"].AxisY.IsLogarithmic = false;
				graph.Series[0].Points.Clear();
				allDataPoints.Clear();
				return;
			}

			double multiplier = 1;
			int numDataPoints = dataLength / 2;
			if (numDataPoints > 100)
			{
				numDataPoints = 100;
				multiplier = ((dataLength / 2.0) - 1) / 100;
			}

			for (int i = 0; i < numDataPoints; i++) {
				int n = (int)Math.Round(i * multiplier); //Calculate n given a tau value.
				if (n == 0)
					n = 1; //Use minimal n if tau is less than the sampling period.
				double currentSum = 0; //Initialize the sum
				for (int j = 0; j < dataLength - (2 * n); j++)
				{
					currentSum += Math.Pow((allDataPoints[j + (2 * n)][1] - (2 * allDataPoints[j + n][1]) + allDataPoints[j][1]), 2);
				}
				//Cumulate the sum squared
				double devAtThisTau = currentSum / (2 * n * n * tau0 * tau0 * (dataLength - (2 * n)));
				//Divide by the coefficient
				dev.Add(Math.Sqrt(devAtThisTau));
				actualTau.Add(n * tau0);
			}

			// Loop through data and do something with it
			graph.ChartAreas["ChartArea1"].AxisX.IsLogarithmic = false;
			graph.ChartAreas["ChartArea1"].AxisY.IsLogarithmic = false;
			graph.Series[0].Points.Clear();
			if (actualTau.Count() < 5)
				return;
			graph.ChartAreas["ChartArea1"].AxisX.IsLogarithmic = true;
			graph.ChartAreas["ChartArea1"].AxisY.IsLogarithmic = true;
			for (int i = 0; i < actualTau.Count; ++i)
			{
				// Calculate magnitude or do something with the new complex data
				graph.Series[0].Points.AddXY(actualTau[i], dev[i]);
			}

			//graph.ResetAutoValues();

			if(actualTau[0] >= 10)
				graph.ChartAreas["ChartArea1"].AxisX.Minimum = 10;
			else if (actualTau[0] >= 1)
				graph.ChartAreas["ChartArea1"].AxisX.Minimum = 1;
			else if (actualTau[0] >= 0.1)
				graph.ChartAreas["ChartArea1"].AxisX.Minimum = 0.1;
			else if (actualTau[0] >= 0.01)
				graph.ChartAreas["ChartArea1"].AxisX.Minimum = 0.01;
			else
				graph.ChartAreas["ChartArea1"].AxisX.Minimum = 0.001;
			graph.ChartAreas["ChartArea1"].AxisX.Maximum = actualTau.Last();

			graph.ChartAreas["ChartArea1"].AxisX.Title = "Time Period (s)";
			graph.ChartAreas["ChartArea1"].AxisY.Title = "Allan Standard Deviation";
			//graph.ChartAreas["ChartArea1"].AxisX.MinorGrid.Interval = 1;

		}

		private enum FilterType
		{
			None,
			LPF,
			HPF
		};

		private int filterLength = 0;
		private FilterType filterType;

		private void filterBar_Scroll(object sender, EventArgs e)
		{
			filterLength = filterBar.Value;
			if (latestDataInterval > 0)
				filterLabel.Text = filterLength.ToString() + " (" + (filterLength * latestDataInterval).ToString() + "ms)";
			else
				filterLabel.Text = filterLength.ToString();
		}

		private void filterTypeBox_SelectedIndexChanged(object sender, EventArgs e)
		{
			switch (filterTypeBox.SelectedIndex)
			{
				case 0:
					if (filterType == FilterType.HPF)
					{
						graph.Series[0].Points.Clear();
						allDataPoints.Clear();
					}
					filterType = FilterType.None;
					filterBar.Minimum = 1;
					minSamplesLabel.Text = filterBar.Minimum.ToString();
					filterBar.Enabled = false;
					filterLength = 0;
					break;
				case 1:
					if (filterType == FilterType.HPF)
					{
						graph.Series[0].Points.Clear();
						allDataPoints.Clear();
					}
					filterType = FilterType.LPF;
					filterBar.Minimum = 1;
					minSamplesLabel.Text = filterBar.Minimum.ToString();
					filterLength = filterBar.Value;
					filterBar.Enabled = true;
					break;
				case 2:
					if (filterType == FilterType.LPF || filterType == FilterType.None)
					{
						graph.Series[0].Points.Clear();
						allDataPoints.Clear();
					}
					filterType = FilterType.HPF;
					filterBar.Minimum = 2;
					minSamplesLabel.Text = filterBar.Minimum.ToString();
					filterLength = filterBar.Value;
					filterBar.Enabled = true;
					
					break;
			}
			updateFilterBarMax();
		}

	}
}
